@@ -38,6 +38,10 @@ def filter_label(label):
                  'mathds', 'mathfrak'
                  ]
     if any(label[1:].startswith(bad) for bad in bad_names):
+        if label == '\\dag':
+            return '\\dagger'
+        elif label == '\\diameter':
+            return '\\O'
         return label[1:]
     else:
         return label
